==> kdeadmin-1.91.tar.bz2: kdeadmin-1.91/kpackage/main.cpp <==
///////////////////////////////////////////////////////////////////////////////
// $Id: main.cpp,v 1.16 2000/03/24 15:45:02 toivo Exp $	
// File  : main.cpp
// Author: Damyan Pepper
// Author: Toivo Pedaste
//
// This is the entry point to the program
///////////////////////////////////////////////////////////////////////////////
#include "../config.h"
#include "kpackage.h"

#include <qfile.h>

#include <kapp.h>
#include <kglobal.h>
#include <klocale.h>
#include <kcmdlineargs.h>
#include <options.h>

#include <kaboutdata.h>

#include "debInterface.h"
#include "kissInterface.h"
#include "slackInterface.h"
#include "fbsdInterface.h"
#ifdef HAVE_RPM
#include "rpmInterface.h"
#endif


static const char *description = 
	I18N_NOOP("KDE Package installer");

static KCmdLineOptions options[] =
{
   { "+[Package]", I18N_NOOP("Package to install"), 0 },
   { 0, 0, 0 }
};

// Keep a global pointer to ksetup
KPKG *kpkg;
KPACKAGE *kpackage;

Params *params;

#ifdef HAVE_RPM
  const int kpinterfaceN = 5;
#else
  const int kpinterfaceN = 4;
#endif
pkgInterface *kpinterface[kpinterfaceN];
 
int main(int argc, char **argv)
{
  KAboutData aboutData( "kpackage", I18N_NOOP("KPackage"), 
			  VERSION, description, KAboutData::License_GPL, 
			//    VERSION, description, 0, 
    "(c) 1999-2000,  Damyan Pepper, Toivo Pedaste");
  KCmdLineArgs::init( argc, argv, &aboutData );
  aboutData.addAuthor( "Damyan Pepper");
  aboutData.addAuthor( "Toivo Pedaste",0, "toivo@ucs.uwa.edu.au");
  KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
  KApplication app;
  
  kpkg = 0;
  params = new Params();

  // Create the application
   
  kpinterface[0] = new DEB();
  kpinterface[1] = new KISS();
#ifdef HAVE_RPM
  kpinterface[2] = new RPM();
  kpinterface[3] = new fbsdInterface();
  kpinterface[4] = new SLACK(); // Also catched BSD packages...
#else
  kpinterface[2] = new fbsdInterface();
  kpinterface[3] = new SLACK(); // Also catched BSD packages...
#endif

  if ( app.isRestored() ) {
    if (KTMainWindow::canBeRestored(1)) {
      kpkg =  new KPKG(app.config());  
      kpkg->restore(1);
    }
  } else {
    // Create the main widget and show it
    kpkg = new KPKG(app.config());
    kpkg->show();
  }

  KCmdLineArgs *args = KCmdLineArgs::parsedArgs();

  if (args->count()) {		// an argument has been given
      kpackage->openNetFile(QFile::decodeName(args->arg(0))); 
                        // install package from argument
  }  else {			// otherwise
    if (!kpkg->prop_restart)
      kpackage->setMode(KPACKAGE::Management, 0, 1); // enter management mode
  }
  args->clear();

  int r = app.exec();		// execute the application

  // delete objects on exit
  delete kpkg;
  for (int i = 0; i < kpinterfaceN; i++) {
    delete kpinterface[i];
  }

  return r;			// return the result
}

==> kdeadmin-3.0.1.tar.bz2: kdeadmin-3.0.1/kpackage/main.cpp <==
///////////////////////////////////////////////////////////////////////////////
// $Id: main.cpp,v 1.30 2001/12/28 00:58:03 mueller Exp $	
// File  : main.cpp
// Author: Damyan Pepper
// Author: Toivo Pedaste
//
// This is the entry point to the program
///////////////////////////////////////////////////////////////////////////////
#include <stdlib.h>

#include "../config.h"
#include "kpackage.h"

#include <qfile.h>

#include <kapplication.h>
#include <kglobal.h>
#include <klocale.h>
#include <kcmdlineargs.h>
#include <options.h>

#include <kaboutdata.h>

#include <kpTerm.h>
#include "debInterface.h"
#include "debAptInterface.h"
#include "debDpkgInterface.h"
#include "kissInterface.h"
#include "slackInterface.h"
#include "fbsdInterface.h"
#ifdef HAVE_RPM
#include "rpmInterface.h"
#endif


static const char *description = 
	I18N_NOOP("KDE Package installer");

static KCmdLineOptions options[] =
{
   { "remote ", I18N_NOOP("Remote host for Debian APT, via SSH"), 0 },
   { "r ", 0, 0},
   { "+[Package]", I18N_NOOP("Package to install"), 0 },
   { 0, 0, 0 }
};

// Globals
KPKG *kpkg;
KPACKAGE *kpackage;
kpPty *kpty;
kpRun *kprun;
kpRun *kpstart;
Opts *opts;

QString hostName;

pkgInterface *kpinterface[kpinterfaceN];
 
int main(int argc, char **argv)
{
  KAboutData aboutData( "kpackage", I18N_NOOP("KPackage"), 
			  VERSION, description, KAboutData::License_GPL, 
			//    VERSION, description, 0, 
    "(c) 1999-2001, Toivo Pedaste");
  KCmdLineArgs::init( argc, argv, &aboutData );
  aboutData.addAuthor( "Toivo Pedaste",0, "toivo@ucs.uwa.edu.au");
  KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
  KApplication app;
  
  setenv("LC_ALL", KGlobal::locale()->language().latin1(), 1);

  kpkg = 0;
  int j = 0;

  KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
  QString remoteHost = args->getOption("remote");
  kdDebug() << "r=" << args->getOption("remote") << "\n";

  if (remoteHost.isEmpty() || remoteHost == "localhost") {
    hostName = "";
  } else {
    hostName = remoteHost;
  }

  kpty = new kpPty();
  kprun = new kpRun();
  kpstart = new kpRun();

  for (int i = 0; i < kpinterfaceN; i++) {
    kpinterface[i] = 0;
  }

  kpinterface[j++] = new DEBDPKG();
  kpinterface[j++] = new DEBAPT();
  kpinterface[j++] = new KISS();
#ifdef HAVE_RPM
  kpinterface[j++] = new RPM();
#endif
  kpinterface[j++] = new fbsdInterface();
  kpinterface[j++] = new SLACK(); // Also catched BSD packages...

  kdDebug() << "R=" << hostName << "\n";
  opts = new Opts(hostName);

  if ( app.isRestored() ) {
    if (KPKG::canBeRestored(1)) {
      kpkg =  new KPKG(app.config());  
      kpkg->restore(1);
    }
  } else {
    // Create the main widget and show it
    kpkg = new KPKG(app.config());
    kpkg->show();
  }
  kpkg->setCaption(hostName);

  if (args->count()) {		// an argument has been given
      kpackage->openNetFile(args->url(0)); 
                        // install package from argument
  }  else {			// otherwise
    if (!kpkg->prop_restart)
      kpackage->setup();
  }
  
  args->clear();

  int r = app.exec();		// execute the application

  // delete objects on exit
  delete kpkg;
  for (int i = 0; i < kpinterfaceN; i++) {
    delete kpinterface[i];
  }

  return r;			// return the result
}
